#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define service download_files
%if 0%{?fedora} || 0%{?rhel}
%define build_pkg_name obs-build
%else
%define build_pkg_name build
%endif
Name:           obs-service-%{service}
Version:        0.9.2
Release:        1.6
Summary:        An OBS source service: download files
License:        GPL-2.0-or-later
URL:            https://github.com/openSUSE/obs-service-%{service}
Source0:        %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{build_pkg_name}
BuildRequires:  bzip2
BuildRequires:  tar
BuildRequires:  (curl or curl-minimal)
BuildRequires:  perl(File::Type)
BuildRequires:  perl(FindBin)
BuildRequires:  perl(HTTP::Server::Simple)
BuildRequires:  perl(Path::Class)
# provides: /usr/bin/prove
BuildRequires:  perl(Test::Harness)
BuildRequires:  perl(Test::More)
Requires:       %{build_pkg_name} >= 2012.08.24
Requires:       curl
Requires:       diffutils
# for appimage parser:
Requires:       perl(YAML::XS)
BuildArch:      noarch

%description
This is a source service for openSUSE Build Service.

This service is parsing all spec files and downloads all Source files which are specified via a http, https or ftp url.

%prep
%autosetup

%build
perl -p -i -e "s{#!%{_bindir}/env bash}{#!/bin/bash}" download_files

%install
%make_install

%check
%make_build test

%files
%doc README.md
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service
%dir %{_sysconfdir}/obs
%dir %{_sysconfdir}/obs/services
%config(noreplace) %{_sysconfdir}/obs/services/*

%changelog
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.2:
  * Reliably detect download failures by using curl -f
  * testing in docker
* Wed Oct 13 2021 Adrian Schröter <adrian@suse.de>
- update to version 0.9.1:
  * supporting alternative local filenames in spec and PKGBUILD
  * Download files only on the "last" *.spec files
  * fixes for silent download
* Tue Aug 24 2021 dcermak@suse.com
- Update to version 0.8.0:
  * updated debian control and changelog
  * added debian.dsc
  * added 'make test' to spec file
  * fix '--recompress'
  * fix test suite
  * added KankuFile
  * added section 'clean' to Makefile
* Tue Apr 27 2021 adrian@suse.de
- Update to version 0.7.2:
  * add install time dependencies
* Mon Feb 22 2021 adrian@suse.de
- Update to version 0.7.1:
  * fix enforceupstream option with cold/disabled cache
* Wed Dec  9 2020 adrian@suse.de
- Update to version 0.7.0:
  * Support modification time header check during download
  * Fedora dependency updates from cfelder
  * fix missing dep for appimage parser
* Wed Jan 16 2019 Adrian Schröter <adrian@suse.de>
- fix dependency to perl(YAML::XS) for appimage parser
* Thu Aug 30 2018 adrian@suse.de
- Update to version 0.6.2:
  * support appimage.yml parsing
* Fri Jun 29 2018 FSchreiner@suse.com
- update to new tag 0.6.1
  * changed _service to @PARENT_TAG@
  * swap wget parameters
  * remove unset urlextension variable
  * remove unused BN
  * remove leftover partial file when wget fails
  * Add missing build-dependencies to d/control
  * [dist] replace shebang to get rid error while building package
  * [dist] remove obsrun user and cachedir from package
* Mon Jun 25 2018 opensuse-packaging@opensuse.org
- Update to version 0.6.0.git.1529932613.88b8b29:
  * [dist] remove obsrun user and cachedir from package
  * [dist] migrate spec file from OBS to git repo
  * debian changelog entry
  * make enforcement of IPv4 and SSL verification optional.
  * Add README.md file
  * fixes #6
  * added gitignore
  * [testing] better handling for files in download server
  * fixed tabs
  * fixed recompression and started with automated testing
* Mon Jun 25 2018 fschreiner@suse.de
- Update to version 0.6.0.git.1529932093.f836107:
  * [dist] migrate spec file from OBS to git repo
* Wed Aug 16 2017 adrian@suse.de
- Update to version 0.6.0.git.1502883896.50fa599: (boo#1053984)
  * make enforcement of IPv4 and SSL verification optional.
* Wed Feb 17 2016 opensuse-packaging@opensuse.org
- Update to version 0.5.1.git.1455712026.9c0a4a0: (boo#967265)
  + prevent tar/cp/rm/mv from malicious filenames
  + added double quotes for some commands
  + Rework code
  + Remove duplicated code
  + fixed recompression and started with automated testing
  + fixed tabs
  + [testing] better handling for files in download server
  + added gitignore
  + fixes #6
* Fri Jul 24 2015 hib@hiberis.nl
- Add debian.dsc
* Fri Jul 24 2015 adrian@suse.de
- Update to version 0.5.1.git.1437716073.690c01e:
  + Fix grammar
  + Add GPL2+ license
  + Add Makefile with install target
  + Debianization
  + Stricter change filename check
* Wed Mar 18 2015 adrian@suse.de
- Update to version 0.5.1.git.1426665567.a5a06e5:
  + Stricter change filename check
  + fix syntax in .service file
* Thu Feb 13 2014 speilicke@suse.com
- Update to version 0.5+git.1392281610.962de91:
  + Generate changes entries from special files
* Wed Feb  5 2014 speilicke@suse.com
- Add source service tar_scm to fetch sources moved to
  https://github.com/openSUSE/obs-service-download_files
- Run spec-cleaner
* Tue Dec 17 2013 adrian@suse.de
- We do not tell the server that we are an OBS tool by default anymore,
  because too many sites just have a white list, but they accept wget
* Tue Jul 16 2013 adrian@suse.de
- fallback to openSUSE 12.3 config if build does not provide default.config
* Mon Jun 24 2013 tchvatal@suse.com
- Fix download from github by explicitly specifying output file.
- Use local scope where possible.
- Add bash comparsions instead of posix ones as bash invoke them
  faster.
- Remove urlextension variable which was always empty.
* Fri Jun 21 2013 andreas.stieger@gmx.de
- move the setting of the wget command inside the loop to start
  new on every iteration. Prevents interference of a specified
  http user agent or output file name with the next loop iteration,
  as it happens when several sources are present in the spec file.
* Wed Jun 19 2013 andreas.stieger@gmx.de
- Determine intended filename from URL fragment
  * allows downloading from URLs not containing a filename, e.g.:
    http://example.com/dl.cgi?{version}#/%%{name}-%%{version}.tar.gz
  * allows downloading from URLS where the file name sent differs
    from the one used in the package, e.g:
    http://example.com/gpgkeys.asc#/%%{name}.keyring
* Mon Nov 19 2012 dimstar@opensuse.org
- Fix useradd invocation: -o is useless without -u and newer
  versions of pwdutils/shadowutils fail on this now.
* Fri Aug 24 2012 mls@suse.de
- also look at PKGBUILD files
* Mon Jan  2 2012 cfarrell@suse.com
- license update: GPL-2.0+
  SPDX format
* Wed Nov 23 2011 adrian@suse.de
- import fixes for recompress & enforcelocal case (by coolo)
* Tue Nov 22 2011 adrian@suse.de
- silence during directory change
* Fri Aug 26 2011 adrian@suse.de
- allow to configure a local cache directory
* Fri Aug 26 2011 adrian@suse.de
- add two new options:
    enforceupstream=yes: package turns into broken state when
    upstreams hosts a different file.
    enforcelocal=yes: package turns into broken state when
    the file was not part of the commit
* Wed Aug 24 2011 adrian@suse.de
- support special download handling for sourceforge.net
* Thu Aug 18 2011 adrian@suse.de
- use own user agent
- handle --outdir . situation
* Tue Jul  5 2011 adrian@suse.de
- Improve error reporting on illegal URLs
- fix "same file as committed" detection
* Tue May 24 2011 adrian@suse.de
- initial package to download files accordings to urls in spec file Source: tags
